package VMOMI::HostLowLevelProvisioningManagerFileType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
